@@ -612,7 +612,7 @@ def open_image():
 class NavigationToolbar(NavigationToolbar):
     # only display the buttons we need
     toolitems = [t for t in NavigationToolbar.toolitems if
-                 t[0] in ('Home', 'Pan', 'Zoom')]
+                 t[0] in ('Pan', 'Zoom')]
 
     def set_message(self, msg):
         pass
